<!doctype html>
<html>
<head>
  {% block head %}
  <title>{% block title %}{% endblock %} - Livestatus-service</title>
  {% endblock %}
</head>
<body>

{% block content %}{% endblock %}

<footer>
  {% block footer %}
  Livestatus service,  version {{ version }} <br>
  &copy; Copyright 2013 ImmobilienScout24
  {% endblock %}
</footer>
</body>
</html>
